<?php
/**
 * Wordpress function Page
 * @package WordPress
 * @subpackage Oneline
 * @since Oneline 1.0
 */
if ( ! isset( $content_width ) ) {
  $content_width = 1170;
}
function oneline_languages() {
load_theme_textdomain('oneline', get_template_directory() . '/languages');
}
add_action( 'init', 'oneline_languages' );
require_once( get_template_directory() . '/inc/include.php' );
/**
 * Register Fonts
 *
 * @return string
 */
function oneline_fonts_url() {
  $fonts_url = '';
  /*
     Translators: If there are characters in your language that are not
     * supported by Roboto or Roboto Slab, translate this to 'off'. Do not translate
     * into your own language.
   */
  $roboto = _x( 'on', 'Roboto font: on or off', 'oneline' );
  $roboto_slab = _x( 'on', 'Roboto Slab font: on or off', 'oneline' );

  if ( 'off' !== $roboto || 'off' !== $roboto_slab ) {
    $font_families = array();

    if ( 'off' !== $roboto ) {
      $font_families[] = 'Roboto:300,400,500,700';
    }

    if ( 'off' !== $roboto_slab ) {
      $font_families[] = 'Roboto Slab:400,700';
    }

    $query_args = array(
      'family' => urlencode( implode( '|', $font_families ) ),
      'subset' => urlencode( 'latin,latin-ext' ),
    );
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
  }
  return $fonts_url;
}

/**
 * Enqueue scripts and styles for the front end.
 *
 */
function oneline_scripts() {
$oneline__animation = get_theme_mod('oneline_animation_disable');
// Add Genericons font, used in the main stylesheet.
if($oneline__animation =='' || $oneline__animation =='0'){
  // Add Genericons font, used in the main stylesheet.
  wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.css', array(), '1.0.0' );
}
  wp_enqueue_style( 'oneline_fonts', oneline_fonts_url(), array(), '1.0.0' );
  wp_enqueue_style( 'oneline-font-awesome-new', get_template_directory_uri() . '/css/font-awesome/css/fontawesome-all.css', array(), '1.0.0' ); 
  wp_enqueue_style( 'oneline-font-awesome-old', get_template_directory_uri() . '/css/font-awesome/css/font-awesome.css', array(), '1.0.0' );
  wp_enqueue_style( 'bx-slider', get_template_directory_uri() . '/css/bxslider.css', array(), '1.0.0' );
  wp_enqueue_style( 'Owl', get_template_directory_uri() . '/css/owl.carousel.css', array(), '1.0.0' );
  wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/css/magnific-popup.css', array(), '1.0.0' );
  wp_enqueue_style('oneline-style', get_stylesheet_uri());
  wp_enqueue_script( 'oneline-classie', get_template_directory_uri() . '/js/classie.js', array( 'jquery' ), '', false );
  wp_enqueue_script( 'oneline-wow-animation', get_template_directory_uri() . '/js/wow.js', array( 'jquery' ), '', true );
  wp_enqueue_script( 'oneline-flexslider', get_template_directory_uri() . '/js/jquery.flexslider.js', array( 'jquery' ), '', true );
  wp_enqueue_script( 'oneline-bxslider-min', get_template_directory_uri() . '/js/jquery.bxslider.js', array( 'jquery' ), '', true );
  wp_enqueue_script( 'oneline-parallax-eft-one', get_template_directory_uri() . '/js/skrollr.js', array( 'jquery' ), '', true );
  wp_enqueue_script( 'oneline-parallax-eft-two', get_template_directory_uri() . '/js/imagesloaded.js', array( 'jquery' ), '', true );
  wp_enqueue_script( 'oneline-isotop', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array( 'jquery' ), '', true );
  wp_enqueue_script( 'oneline-owl', get_template_directory_uri() . '/js/owl.carousel.js', array( 'jquery' ), '', true );
  wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array( 'jquery' ), '', true );
  wp_enqueue_script( 'oneline-custom', get_template_directory_uri() . '/js/custom.js', array( 'jquery' ), '', true );
    wp_localize_script( 'oneline-custom', 'frontendajax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' )));
  // Comment reply
  if (is_singular() && get_option('thread_comments')){
    wp_enqueue_script('comment-reply');
  }
}
add_action( 'wp_enqueue_scripts', 'oneline_scripts' );
add_action( 'after_setup_theme', 'oneline_theme_setup' );
function oneline_theme_setup() {
// Add RSS feed links to <head> for posts and comments.
    add_theme_support( 'automatic-feed-links' );

    /*
     * Enable support for Post Formats.
     */

    add_theme_support( 'post-formats', array(
         'gallery','video', 'audio', 'link','quote'
    ) );
    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

    /*
   * Let WordPress manage the document title.
   * By adding theme support, we declare that this theme does not use a
   * hard-coded <title> tag in the document head, and expect WordPress to
   * provide it for us.
   */
 add_theme_support( 'title-tag' );
 add_theme_support( 'custom-logo', array(
    'height'      => 60,
    'width'       => 225,
    'flex-height' => true,
  ) );

/* woocommerce support */
$defaults = array(
    'default-image'          =>'',
    'flex-height'            => false,
    'flex-width'             => false,
    'uploads'                => true,
    'random-default'         => false,
    'header-text'            => false,
    'default-text-color'     => '',
    'wp-head-callback'       => '',
    'admin-head-callback'    => '',
    'admin-preview-callback' => '',
);
add_theme_support( 'custom-header', $defaults );
add_theme_support( 'woocommerce' );
$args = array(
  'default-color' => 'f7f7f7',
);
add_theme_support( 'custom-background', $args );
}
// add scroll class
function add_menuclass($ulclass) {
   return preg_replace('/<a /', '<a class="page-scroll"', $ulclass);
}
add_filter('wp_nav_menu','add_menuclass');
/**
  * dynamic social link
  *
  */
function oneline_social_links(){
?>
<ul>
<?php if($f_link = get_theme_mod('social_link_facebook')) : ?><li><a target='_blank' href="<?php echo $f_link; ?>" ><i class='fa fa-facebook'></i></a></li><?php endif; ?>
<?php if($t_link = get_theme_mod('social_link_google')) : ?><li><a target='_blank' href="<?php echo $t_link; ?>" ><i class='fa fa-google-plus'></i></a></li><?php endif; ?>
<?php if($g_link = get_theme_mod('social_link_linkedin')) : ?><li><a target='_blank' href="<?php echo $g_link; ?>" ><i class='fa fa-linkedin'></i></a></li><?php endif; ?>
<?php if($l_link = get_theme_mod('social_link_pintrest')) : ?><li><a target='_blank' href="<?php echo $l_link; ?>" ><i class='fa fa-pinterest'></i></a></li><?php endif; ?>
<?php if($p_link = get_theme_mod('social_link_twitter')) : ?><li><a target='_blank' href="<?php echo $p_link; ?>" ><i class='fa fa-twitter'></i></a></li><?php endif; ?>
<?php if($in_link = get_theme_mod('social_link_insta')) : ?><li><a target='_blank' href="<?php echo $in_link; ?>" ><i class="fab fa-instagram"></i></a></li><?php endif; ?>
    </ul>

<?php } ?>